This is an automated email from the ASF dual-hosted git repository.

cshannon pushed a commit to branch elasticity
in repository https://gitbox.apache.org/repos/asf/accumulo.git


The following commit(s) were added to refs/heads/elasticity by this push:
     new a545e1e45e Update ITs to account for new scan ref table (#4650)
a545e1e45e is described below

commit a545e1e45e37d6ffcf3b571f5ed599d27ce4f4c8
Author: Christopher L. Shannon <cshan...@apache.org>
AuthorDate: Sat Jun 8 12:44:44 2024 -0400

    Update ITs to account for new scan ref table (#4650)
---
 test/src/main/java/org/apache/accumulo/test/MetaSplitIT.java          | 4 ++--
 test/src/main/java/org/apache/accumulo/test/NamespacesIT.java         | 2 +-
 .../apache/accumulo/test/functional/TabletManagementIteratorIT.java   | 3 ++-
 3 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/test/src/main/java/org/apache/accumulo/test/NamespacesIT.java 
b/test/src/main/java/org/apache/accumulo/test/NamespacesIT.java
index 80d47f23d3..0835c43346 100644
--- a/test/src/main/java/org/apache/accumulo/test/NamespacesIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/NamespacesIT.java
@@ -134,7 +134,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
         c.tableOperations().delete(t);
       }
     }
-    assertEquals(3, c.tableOperations().list().size());
+    assertEquals(4, c.tableOperations().list().size());
     for (String n : c.namespaceOperations().list()) {
       if (!n.equals(Namespace.ACCUMULO.name()) && 
!n.equals(Namespace.DEFAULT.name())) {
         c.namespaceOperations().delete(n);
diff --git a/test/src/main/java/org/apache/accumulo/test/MetaSplitIT.java 
b/test/src/main/java/org/apache/accumulo/test/MetaSplitIT.java
index 5bbab1b173..885721a5e2 100644
--- a/test/src/main/java/org/apache/accumulo/test/MetaSplitIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/MetaSplitIT.java
@@ -193,8 +193,8 @@ public class MetaSplitIT extends AccumuloClusterHarness {
             && !e.getKey().equals(AccumuloTable.METADATA.tableName()))
         .map(Map.Entry::getValue).map(TableId::of).map(tid -> new 
KeyExtent(tid, null, null))
         .collect(Collectors.toSet());
-    // Verify we have 11 tablets for metadata (Includes FateTable)
-    assertEquals(11, expectedExtents.size());
+    // Verify we have 12 tablets for metadata (Includes FateTable and ScanRef 
table)
+    assertEquals(12, expectedExtents.size());
 
     // Scan each tablet to verify data exists
     var ample = ((ClientContext) client).getAmple();
diff --git 
a/test/src/main/java/org/apache/accumulo/test/functional/TabletManagementIteratorIT.java
 
b/test/src/main/java/org/apache/accumulo/test/functional/TabletManagementIteratorIT.java
index fc6d42fe35..ab703d2753 100644
--- 
a/test/src/main/java/org/apache/accumulo/test/functional/TabletManagementIteratorIT.java
+++ 
b/test/src/main/java/org/apache/accumulo/test/functional/TabletManagementIteratorIT.java
@@ -524,7 +524,8 @@ public class TabletManagementIteratorIT extends 
AccumuloClusterHarness {
       }
     }
 
-    // metadata should be stable with only 9 rows (2 for each table) + 1 for 
the FateTable
+    // metadata should be stable with only 9 rows (2 for each table)
+    // + 2 for the FateTable and ScanRef table
     log.debug("Gathered {} rows to create copy {}", mutations.size(), copy);
     assertEquals(9, mutations.size(),
         "Metadata should have 8 rows (2 for each table) + one row for "

Reply via email to